==> elpoint-0.1.0.tar.gz: elpoint-0.1.0/ept-mode.el <==
;;; ept-mode.el --- Major mode for Elpoint editing.

;; Copyright (C) 2002 Yuuichi Teranishi <teranisi@gohome.org>

;; Author: Yuuichi Teranishi <teranisi@gohome.org>
;; Keywords: Presentation

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.
;;

;;; Commentary:
;; 

;;; History:
;; 
(eval-when-compile
  (require 'cl))

(require 'ept)
(require 'derived)

;;; Code:
(define-derived-mode ept-mode emacs-lisp-mode "Elpoint"
  "Elpoint editor mode derived from emacs-lisp mode.")

(define-key ept-mode-map "\C-c\C-e" 'ept-exec-buffer)
(define-key ept-mode-map "\C-c\C-d" 'ept-dump-buffer)
(define-key ept-mode-map "\C-c\C-n" 'ept-number)

(defun ept-number ()
  (interactive)
  (let ((pages 0)
	(pos (point)))
    (save-excursion
      (goto-char (point-min))
      (while (re-search-forward "^ *(ept-page" pos t)
	(incf pages)))
    (when (interactive-p)
      (message "Page %d" (setq pages (max 0 (- pages 1)))))
    pages))

(defsubst ept-exec-internal (start-page &optional dump)
  (let ((source (current-buffer))
	work presentation)
    (with-temp-buffer
      (setq work (current-buffer))
      (with-current-buffer source
	(copy-to-buffer work (point-min) (point-max)))
      (goto-char (point-min))
      (insert "(")
      (goto-char (point-max))
      (insert ")")
      (goto-char (point-min))
      (setq presentation (read (current-buffer))))
    (ept-play presentation start-page dump)))

(defun ept-exec-file (&optional file)
  (interactive "fFile: ")
  (find-file file)
  (let ((buffer (current-buffer)))
    (unwind-protect
	(ept-exec-buffer)
      (kill-buffer buffer))))

(defun ept-dump-file (&optional file)
  (interactive "fFile: ")
  (find-file file)
  (let ((buffer (current-buffer)))
    (unwind-protect
	(ept-dump-buffer)
      (kill-buffer buffer))))

(defun ept-exec-buffer (&optional from-current)
  "Play current buffer content as an Elpoint presentation.
If optional FROM-CURRENT is non-nil, start from the page under the cursor."
  (interactive "P")
  (ept-exec-internal (if from-current (ept-number) 0)))

(defun ept-dump-buffer (&optional dir)
  "Play current buffer content as an Elpoint presentation and dump it to DIR."
  (interactive "DOutput Directory: ")
  (let ((ept-dump-directory dir))
    (ept-exec-internal 0 'dump)))

(provide 'ept-mode)

;;; ept-mode.el ends here

==> elpoint-0.1.1.tar.gz: elpoint-0.1.1/ept-mode.el <==
;;; ept-mode.el --- Major mode for Elpoint editing.

;; Copyright (C) 2002 Yuuichi Teranishi <teranisi@gohome.org>

;; Author: Yuuichi Teranishi <teranisi@gohome.org>
;; Keywords: Presentation

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.
;;

;;; Commentary:
;; 

;;; History:
;; 

;;; Code:
(eval-when-compile
  (require 'cl))

(require 'ept)
(require 'derived)

(defcustom ept-mode-hook nil
  "A hook called after elpoint editing mode."
  :group 'ept
  :type 'hook)

(define-derived-mode ept-mode emacs-lisp-mode "Elpoint"
  "Elpoint editor mode derived from emacs-lisp mode."
  (run-hooks 'ept-mode-hook))

(define-key ept-mode-map "\C-c\C-e" 'ept-exec-buffer)
(define-key ept-mode-map "\C-c\C-d" 'ept-dump-buffer)
(define-key ept-mode-map "\C-c\C-n" 'ept-number)

(defun ept-number ()
  (interactive)
  (let ((pages 0)
	(pos (point)))
    (save-excursion
      (goto-char (point-min))
      (while (re-search-forward "^ *(ept-page" pos t)
	(incf pages)))
    (when (interactive-p)
      (message "Page %d" (setq pages (max 0 (- pages 1)))))
    pages))

(defsubst ept-exec-internal (start-page &optional dump)
  (let ((source (current-buffer))
	work presentation)
    (with-temp-buffer
      (setq work (current-buffer))
      (with-current-buffer source
	(copy-to-buffer work (point-min) (point-max)))
      (goto-char (point-min))
      (insert "(")
      (goto-char (point-max))
      (insert ")")
      (goto-char (point-min))
      (setq presentation (read (current-buffer))))
    (ept-play presentation start-page dump)))

(defun ept-exec-file (&optional file)
  (interactive "fFile: ")
  (find-file file)
  (let ((buffer (current-buffer)))
    (unwind-protect
	(ept-exec-buffer)
      (kill-buffer buffer))))

(defun ept-dump-file (&optional file)
  (interactive "fFile: ")
  (find-file file)
  (let ((buffer (current-buffer)))
    (unwind-protect
	(ept-dump-buffer)
      (kill-buffer buffer))))

(defun ept-exec-buffer (&optional from-current)
  "Play current buffer content as an Elpoint presentation.
If optional FROM-CURRENT is non-nil, start from the page under the cursor."
  (interactive "P")
  (ept-exec-internal (if from-current (ept-number) 0)))

(defun ept-dump-buffer (&optional dir)
  "Play current buffer content as an Elpoint presentation and dump it to DIR."
  (interactive "DOutput Directory: ")
  (ept-exec-internal 0 dir))

(provide 'ept-mode)

;;; ept-mode.el ends here
